@@ -1,6 +1,6 @@
 @c -*-texinfo-*-
 @c This is part of the GNU edition of V.E.R.A.
-@c Copyright (C) 1993/2014 Oliver Heidelbach
+@c Copyright (C) 1993/2020 Oliver Heidelbach
 @c See the file vera.texi for copying conditions.
 @c 
 @c Syntax:
@@ -9,9 +9,14 @@
 @c Additional explanations are included in [square brackets]
 
 @table @asis
+C&C          Command & Control [server]
+
 @item C128
 Commodore 128 [computer] (Commodore)
 
+@item C2DM
+Cloud to Device Messaging (Google)
+
 @item C2IS
 Command and Control Information Systems (mil., USA)
 
@@ -30,6 +35,9 @@ Command, Control, Communications, Computers and Intelligence (mil., USA)
 @item C64
 Commodore 64 [computer] (Commodore)
 
+@item CA
+Carrier Aggregation
+
 @item CA
 Cell Arrival (ATM)
 
@@ -45,12 +53,24 @@ Computer Animation
 @item CA
 Computer Associates (manufacturer)
 
+@item CAA
+Certification Authority Authorization (DNS, RFC 6844)
+
 @item CAAD
 Computer Aided Architectural Design
 
+@item CAAS
+Container As A Service, "CaaS"
+
+@item CAB
+Contextual Action Bar (Android)
+
 @item CABAC
 Context Based Adaptive Binary Arithmetic Coding (AVC)
 
+@item CABC
+Content Adaptive Brightness Control (Dell)
+
 @item CABS
 Carrier Access Billing System
 
@@ -108,6 +128,9 @@ Computer Aided Inspection (CIM)
 @item CAI
 Computer Aided Instruction
 
+@item CAIDA
+Center for Applied Internet Data Analysis (org.)
+
 @item CAIP
 Computer Analysis of Images and Patterns (Konferenz)
 
@@ -132,6 +155,9 @@ Computer Assisted Learning
 @item CAL
 Conversational Algebraic Language (JOSS)
 
+@item CAL
+Cryptographic Autonomy License
+
 @item CALEA
 Communications Assistance Law Enforcement Act (USA)
 
@@ -186,6 +212,9 @@ Computer Aided Office
 @item CAO
 Control Area Operator (EMS)
 
+@item CAP
+CAMEL Application Part (SS7, CAMEL)
+
 @item CAP
 Carrierless Amplitude Phase [modulation] (ADSL, AT&T)
 
@@ -207,6 +236,9 @@ Computer Aided Publishing
 @item CAP
 Consistency, Availability, Partition tolerance
 
+@item CAP
+Cross Account Protection (Google)
+
 @item CAPE
 Computer Applications in Production and Engineering (conference, IFIP)
 
@@ -318,6 +350,9 @@ Carlisle Adams and Stafford Tavares (cryptography)
 @item CAST
 Computer Aided Software Testing
 
+@item CAT
+Cache Allocation Technology (Intel)
+
 @item CAT
 Central Alaska Time [-1000] (TZ)
 
@@ -337,7 +372,7 @@ Computer Aided Testing
 Condition Access Table (DVB)
 
 @item CATI
-Computer Aided Telephone Interviewing
+Computer Aided / Assisted Telephone Interviewing
 
 @item CATIA
 Computer Aided Three-Dimensional Interactive Application (CAD)
@@ -372,6 +407,9 @@ Computer Associates - Visual Objects (CA, DB), "CA-VO"
 @item CBASIC
 Commercial Beginners All purpose Symbolic Instruction Code (BASIC)
 
+@item CBB
+Current Branch for Business (MS, Windows)
+
 @item CBC
 Cipher Block Chaining [mode] (DES, DESE, RC5, cryptography)
 
@@ -420,6 +458,9 @@ Class Based Queueing
 @item CBR
 Constant Bit Rate (ATM, VBR, ABR, UBR, QOS, BIT)
 
+@item CBRAM
+Conductive Bridging Random Access Memory (RAM, IC)
+
 @item CBS
 Certified Banyan Specialist (Banyan, VINES)
 
@@ -588,6 +629,9 @@ Communications Control Program (OS, IBM)
 @item CCP
 Compact Communication Products (TPS)
 
+@item CCPI
+Cavium Coherent Processor Interconnect
+
 @item CCPP
 Composite Capability / Preference Profiles (W3C, RDF), "CC/PP"
 
@@ -663,6 +707,9 @@ C-bit Coding Violation [error event] (DS3/E3, BIT)
 @item CCW
 COM Callable Wrapper (MS, COM, Java)
 
+@item CCX
+CPU Core compleX (CPU)
+
 @item CD
 Carrier Detect (MODEM, RS-232)
 
@@ -696,6 +743,9 @@ Connectionless Data Bearer Service
 @item CDBX
 Computerized Digital Branch eXchange (PBX)
 
+@item CDC
+Communication Device Class (USB, MS, Windows, WMCDC)
+
 @item CDC
 Connected Device Configuration (JVM)
 
@@ -705,6 +755,9 @@ Control Data Corporation (manufacturer)
 @item CDC
 Cult of the Dead Cow (org.), "cDc"
 
+@item CDD
+Compatibility Definition Document (Android)
+
 @item CDD
 Component Design Document
 
@@ -714,6 +767,9 @@ Compact Disk - Digital Audio (CD, Digital audio), "CD-DA"
 @item CDDI
 Copper Distributed Data Interface (FDDI, UTP)
 
+@item CDDL
+Common Development and Distribution License
+
 @item CDE
 Certified Directory Engineer (Novell, Netware)
 
@@ -750,12 +806,18 @@ CASE Data Interchange Format (CASE)
 @item CDK
 Control Development Toolkit (MS, VB)
 
+@item CDL
+Controlled Digital Lending
+
 @item CDM
 Compressed Data Mode
 
 @item CDM
 Conceptional Data Model (DB, PDM, Powerdesigner)
 
+@item CDM
+Content Decryption Module (cryptography)
+
 @item CDMA
 Code Division Multiple Access (telecommunication, mobile-systems)
 
@@ -789,6 +851,9 @@ Collaboration Data Objects (WSH, MS)
 @item CDO
 Common Data Objects (MS, ASP)
 
+@item CDP
+Chrome Debugging Protocol
+
 @item CDPC
 Cellular Digital Packet Data
 
@@ -879,6 +944,9 @@ Compact Edition (MS, Windows)
 @item CE
 Connection Endpoint (UNI)
 
+@item CEA
+Capability-Exchange-Answer (CER, Diameter)
+
 @item CEARCH
 Cisco Educational ARCHive (Cisco, WWW)
 
@@ -886,7 +954,7 @@ Cisco Educational ARCHive (Cisco, WWW)
 welt CEntrum Buero Information Telekommunikation (fair), "CeBIT"
 
 @item CEC
-Consumer Electronics Control [protocol]
+Consumer Electronics Control [protocol] (HDMI)
 
 @item CECI
 CICS Enhanced Command Interpreter (IBM, CICS)
@@ -906,6 +974,9 @@ CICS Execution Diagnostic Facility (CICS, IBM)
 @item CEE
 [Linux] Consumer Electronics Edition (MontaVista, Linux, PDA)
 
+@item CEE
+Converged Enhanced Ethernet
+
 @item CEECEB
 Central and Eastern European Countries EDIFACT Board (org., EDIFACT), "CEEC/EB"
 
@@ -918,6 +989,9 @@ Continuous Edge Graphics (Grafik, IC)
 @item CEI
 Connection Endpoint Identifier (UNI)
 
+@item CEIP
+Customer Experience Improvement Program (MS)
+
 @item CELL
 CIP/Ethernet Library for Linux (Linux, ethernet, CIP, PLC)
 
@@ -948,12 +1022,18 @@ Council of European National Top level Domain Registries (org., TLD)
 @item CEPAC
 CMOS-Ein-Platinen-Allzweck-Computer (IC, CMOS, C'T)
 
+@item CEPD
+Comite Europeen de la Protection des Donnees (org.)
+
 @item CEPIS
 Council of European Professional Informatics Societies (org., Europe)
 
 @item CEPT
 Conference of European Postal and Telecommunications administrations (org., CCITT, conference, Europe)
 
+@item CER
+Capability-Exchange-Request (CEA, Diameter)
+
 @item CER
 Cell Error Ratio (ATM)
 
@@ -976,7 +1056,7 @@ Character Encoding Scheme (CSS, Unicode)
 Circuit Emulation Service
 
 @item CES
-Consumer Electronics Show (fair, USA)
+Consumer Electronics Show (fair, USA, CTA)
 
 @item CESAR
 Central Employment Search And Retrieval (WWW)
@@ -1005,6 +1085,9 @@ Center for Architecture (org., JIEO, DISA)
 @item CFA
 Code Fields Address (Forth)
 
+@item CFAA
+Computer Fraud and Abuse Act (USA)
+
 @item CFB
 Cipher FeedBack [mode] (cryptography, DES)
 
@@ -1152,6 +1235,9 @@ Computers in Higher Education Software Team (org., UK)
 @item CHILL
 CCITT HIgh Level programming Language (CCITT)
 
+@item CHPE
+Compiled Hybrid Portable Executable
+
 @item CHRP
 Common Hardware Reference Platform (AIM)
 
@@ -1305,6 +1391,9 @@ Committed Information Rate (ATM)
 @item CIRC
 Cross Interleaved Reed-solomon Code (CD)
 
+@item CIRCAMP
+Cospol Internet Related Child Abusive Material Project (org.)
+
 @item CIRCIT
 Centre for International Research on Communication and Information Technology (org., Australia)
 
@@ -1323,6 +1412,9 @@ Contact Image Sensor
 @item CISA
 Certified Information Systems Auditor (ISACA)
 
+@item CISA
+Cybersecurity and Infrastructure Security Agency (org.)
+
 @item CISC
 Complex Instruction Set Computer (CPU)
 
@@ -1413,6 +1505,9 @@ Custom Local Area Signaling Service
 @item CLDC
 Connected Limited Device Configuration (KVM, CDC, Java, JSR-139)
 
+@item CLDR
+Common Locale Data Repository (Android)
+
 @item CLE
 Certified Linux Engineer (Novell, Linux)
 
@@ -1506,9 +1601,15 @@ Color LookUp Table (VGA)
 @item CLV
 Constant Linear Velocity (CD, MOD)
 
+@item CLX
+Cascade Lake Xeon (Intel, CPU)
+
 @item CLX
 Class Library for cross platform (Delphi, Windows, Linux)
 
+@item CLXAP
+Cascade Lake Xeon - Advanced Performance (Intel,CPU), "CLX-AP"
+
 @item CM
 Compatibility Mode (PARISC, NM)
 
@@ -1521,6 +1622,9 @@ Configuration Manager (BIOS, PNP)
 @item CM
 Connection Management (RR, MM, GSM, mobile-systems)
 
+@item CM
+CyanogenMod (Android)
+
 @item CM2
 Communication Manager /2 (IBM), "CM/2"
 
@@ -1632,6 +1736,9 @@ Cryptographic Message Syntax (cryptography, RFC 2630)
 @item CMT
 Connection ManagemenT (FDDI)
 
+@item CMTC
+Critical Machine-Type Communication (MTC, 3GPP), "C-MTC"
+
 @item CMTS
 Cable MODEM Termination System (DOCSIS, MODEM)
 
@@ -1731,6 +1838,9 @@ Communications Network for Manufacturing Applications
 @item CNMS
 Cylink Network Management System
 
+@item CNN
+Convolutional Neural Network
+
 @item CNNIC
 China interNet Network Information Center (org., Internet, China)
 
@@ -1812,6 +1922,9 @@ Central Office Data Connecting Facility
 @item CODE
 Client/server Open Development Environment (Powersoft)
 
+@item CODE
+Collabora Online Development Edition
+
 @item CODE
 COlor Depth Enhancement (ATI)
 
@@ -1914,6 +2027,9 @@ Child Online Protection Act (Internet, USA, CIPA)
 @item COPP
 Certified Output Protection Protocol (MS, RSA, WPE)
 
+@item COPPA
+Children's Online Privacy Protection Act (Internet)
+
 @item COPS
 Common Open Policy Service protocol (RFC 2748)
 
@@ -1929,9 +2045,15 @@ Communication ORiented Application aNalysis
 @item CORBA
 Common Object Request Broker Architecture (OMG)
 
+@item CORD
+Central Office Re-architected as a Datacenter (ONF)
+
 @item CORDIS
 COmmunity Research and Development Information Service (Europe)
 
+@item CORS
+Cross-Origin Resource Sharing (HTML)
+
 @item COS
 Card Operating System (OS, ICC)
 
@@ -2172,6 +2294,9 @@ Configurable PostScript Interpreter
 @item CPSR
 Computer Professionals for Social Responsibility (org., USA)
 
+@item CPTA
+China Power Technology Alliance (org.)
+
 @item CPTWG
 Copyright Protection Technical Working Group (DVB, WG)
 
@@ -2184,6 +2309,9 @@ Central Processing Unit IDentifier (CPU)
 @item CPW
 Cross-Platform Windowing [library] (OpenGL)
 
+@item CQD
+Carbon Quantum Dots
+
 @item CQL
 Cassandra Query Language
 
@@ -2202,6 +2330,9 @@ Cache RAM (RAM)
 @item CRAM
 Card Random Access Memory (RAM, IC)
 
+@item CRAN
+Comprehensive R Archive Network
+
 @item CRAS
 Cable Repair Administrative System
 
@@ -2232,6 +2363,9 @@ Connection Related Function Virtual Channel (UPC, UNI), "CRF(VC)"
 @item CRFVP
 Connection Related Function Virtual Path (UPC, UNI), "CRF(VP)"
 
+@item CRI
+Container Runtime Interface
+
 @item CRI
 Cray Research, Inc. (manufacturer)
 
@@ -2298,6 +2432,9 @@ Cathode Ray Tube Controller (EGA, VGA, MCGA)
 @item CRTM
 Core Root of Trust for Management (TCPA)
 
+@item CRUD
+Create, Read, Update, Delete
+
 @item CS
 Carrier Selection
 
@@ -2340,12 +2477,18 @@ Communication Streaming Architecture (Intel, MCH, DNB)
 @item CSA
 Configuration Status Accounting
 
+@item CSAIL
+Computer Science and Artificial Intelligence Labs (MIT)
+
 @item CSAPI
 Common Speller Application Program Interface (API)
 
 @item CSC
 Computer Sciences Corporation (provider)
 
+@item CSC
+Consumer Software Customization
+
 @item CSCC
 Concurrent SuperComputing Consortium (org.)
 
@@ -2394,9 +2537,15 @@ Centre Suisse d'Electronique et de Microtecnique (org., Switzerland)
 @item CSES
 C-bit Severely Errored Seconds (DS3/E3, BIT)
 
+@item CSFB
+Circuit Switched FallBack (LTE, UMTS, GSM)
+
 @item CSG
 Constructive Solid Geometry (CAD, CAM)
 
+@item CSGO
+Counter-Strike: Global Offensive, "CS:GO"
+
 @item CSH
 C SHell (Unix, BSD, Shell)
 
@@ -2439,6 +2588,9 @@ Commercial Stable Image Platform (AMD)
 @item CSIRO
 Commonwealth Scientific and Industrial Research Organization (org., UK)
 
+@item CSIRT
+Computer Security Incident Response Team
+
 @item CSIS
 Central Schengen Information Systen (SIS, Europe, Strasbourg)
 
@@ -2497,7 +2649,7 @@ Cloud Service Provider
 Communicating Sequential Processes
 
 @item CSP
-Content Security Policy (Mozilla, Firefox)
+Content Security Policy (WWW)
 
 @item CSP
 Cross System Product (IBM)
@@ -2586,6 +2738,9 @@ Comma Separated Values
 @item CT
 [magazin fuer] Computer Technik, "c't" 
 
+@item CT
+Certificate Transparency
+
 @item CT
 Chipcard Terminal (ICC, CT)
 
@@ -2595,8 +2750,11 @@ Chips & Technologies (manufacturer), "C&T"
 @item CT
 Clackamas Technology (Intel, Pentium, CPU)
 
+@item CTA
+Consumer Technology Association (org.)
+
 @item CTAN
-Comprehensive Tex Archive Network (TeX, FTP)
+Comprehensive Tex Archive Network (TeX, FTP), pause
 
 @item CTAPI
 Chipcard Terminal Application Program Interface (ICC, CT, API), "CT-API"
@@ -2724,6 +2882,9 @@ Color Universal Design (Eizo, LCD)
 @item CUDA
 Compute Unified Device Architecture (Nvidia, 3D)
 
+@item CUE
+Corsair Utility Engine
+
 @item CUI
 Character User Interface (UI)
 
@@ -2796,6 +2957,9 @@ Centrum voor Wiskunde en Informatica (org., Netherlands)
 @item CWIS
 Campus Wide Information System
 
+@item CWM
+ClockworkMod Recovery (Android)
+
 @item CWMI
 Common Warehousing Metadata Interchange (DB, DWH)
 
