@@ -1,6 +1,6 @@
 @c -*-texinfo-*-
 @c This is part of the GNU edition of V.E.R.A.
-@c Copyright (C) 1993/2014 Oliver Heidelbach
+@c Copyright (C) 1993/2020 Oliver Heidelbach
 @c See the file vera.texi for copying conditions.
 @c 
 @c Syntax:
@@ -24,6 +24,9 @@ FernmeldeAmt (DTAG)
 @item FAA
 Flow Admission Acknowledge [message] (LFAP)
 
+@item FAAS
+Function As A Service, "FaaS"
+
 @item FABS
 Fast Access Btree Structure
 
@@ -63,6 +66,9 @@ Flash Authority Identification Data (EEPROM)
 @item FAIS
 Finnish Artificial Intelligence Society (org., Finland, AI)
 
+@item FAL
+File Abstraction Layer (TYPO3)
+
 @item FAL
 File Access Listener (DEC, DNA)
 
@@ -117,8 +123,11 @@ First Application System Test
 @item FAST
 Forschungsinstitut fuer Angewandte Software-Technologie [e.v.] (org.)
 
+@item FASTA
+FAhrzeugbetriebs- und Servicedaten-Transfer und -Analyse (BMW)
+
 @item FAT
-File Allocation Table (DOS)
+File Allocation Table (DOS, FS)
 
 @item FATA
 Fibre-Attached Technology Adapted (HP, SATA, HDD)
@@ -165,6 +174,9 @@ Feedback Control
 @item FC
 Fibre Channel (FC)
 
+@item FC
+Force Close (Android)
+
 @item FC
 Frame Control (FDDI, Token Ring)
 
@@ -327,6 +339,9 @@ Free Documentation License (GNU)
 @item FDM
 Frequency Division Multiplexing (FDM)
 
+@item FDM
+Fused Deposition Modelling
+
 @item FDMA
 Frequency Division Multiple Access (mobile-systems)
 
@@ -387,6 +402,9 @@ Fujitsu Enhanced Imaging Technology (Fujitsu)
 @item FEK
 File Encryption Key (cryptography)
 
+@item FEM
+Fabric Expander Module (Dell, FSE)
+
 @item FEM
 Finite Elemente Methode
 
@@ -429,6 +447,9 @@ First Failure Data Capture
 @item FFDT
 FDDI Full Duplexing Technology (FDDI)
 
+@item FFF
+Fused Filament Fabrication
+
 @item FFFS
 Failsafe Flash File System (FS, Flash), "F3S"
 
@@ -468,9 +489,15 @@ Fine Grained Password Policy (AD)
 @item FGREP
 Fixed Global Regular Expression Print (Unix, GREP)
 
+@item FHE
+Fully Homomorphic Encryption (cryptography)
+
 @item FHGS
 FreeHand Graphics Studio (Macromedia, DTP)
 
+@item FHIR
+Fast Healthcare Interoperability Resources (USA)
+
 @item FHS
 File system Hierarchy Standard (Linux, LSB)
 
@@ -645,6 +672,9 @@ Faithful Library about Internet Message (EMACS, GNU)
 @item FLOPS
 FLoating-point Operations Per Second (CPU)
 
+@item FLOSS
+Free, Libre, and Open Source Software
+
 @item FLOWR
 For, Let, Order by, Where, Return [principle] (DB, XML)
 
@@ -684,6 +714,9 @@ Flip Mount Super Back-plate (Scythe), F.M.S.B.
 @item FMTEYEWTK
 Far More Than Everything You Ever Wanted To Know (slang, PERL)
 
+@item FMV
+Full Motion Video [game]
+
 @item FNC
 Federal Networking Council (org., USA)
 
@@ -720,6 +753,9 @@ Formal specification of ODA document structures (ODA, ISO)
 @item FOEBUD
 [verein zur] Foerderung des OEffentlichen Bewegten und Unbewegten Datenverkehrs [e.v.] (org.), "FoeBuD"
 
+@item FOIP
+Face Over Internet Protocol (IP), "FoIP"
+
 @item FOIRL
 Fiber Optic InterRepeater Link (OWG)
 
@@ -838,7 +874,7 @@ Field Programmable Function Array
 Field Programmable Gate Array (RL)
 
 @item FPI
-Flux Changes per Inch (HDD)
+Flux changes Per Inch (HDD)
 
 @item FPI
 Formal Public Identifier (DTD, SGML, SI)
@@ -981,6 +1017,9 @@ File System Consistency checK (Unix)
 @item FSD
 File System Driver
 
+@item FSE
+Fabric Switch Engine (Dell, FEM)
+
 @item FSF
 Free Software Foundation (org., GNU)
 
@@ -1023,6 +1062,9 @@ Free Standing Operating System (OS)
 @item FSP
 File Slurping Protocol
 
+@item FSP
+Firmware Support Package (Intel)
+
 @item FSPF
 Fibre channel Shortest Path First
 
@@ -1077,6 +1119,9 @@ Federal Trade Commission (org., USA)
 @item FTE
 [DCOM] For The Enterprise (DCOM, SAG)
 
+@item FTF
+Flash Tool Firmwares (Android)
+
 @item FTL
 Flash Translation Layer
 
@@ -1137,6 +1182,9 @@ Fibre To The Node (FTTH)
 @item FTZ
 FernmeldeTechnische Zentralamt / Zulassung (DTAG, ZZF, predecessor)
 
+@item FTZ
+Flush To Zero (DAZ)
+
 @item FUA
 Flow Update Acknowledge [message] (LFAP)
 
@@ -1176,6 +1224,12 @@ Fernmeldeanlagen-UEberwachungsVerordnung
 @item FVD
 Forward Versatile Disc (China, WMV)
 
+@item FVWM
+F Virtual Window Manager
+
+@item FWA
+Fixed Wireless Access
+
 @item FWH
 FirmWare Hub (BIOS, Intel)
 
