@@ -1,6 +1,6 @@
 @c -*-texinfo-*-
 @c This is part of the GNU edition of V.E.R.A.
-@c Copyright (C) 1993/2014 Oliver Heidelbach
+@c Copyright (C) 1993/2020 Oliver Heidelbach
 @c See the file vera.texi for copying conditions.
 @c 
 @c Syntax:
@@ -45,12 +45,21 @@ Houston Area League of PC-Users, "HAL-PC"
 @item HAMPS
 Host AUTODIN Message Processing System (AUTODIN, mil.)
 
+@item HAMR
+Heat Assisted Magnetic Recording (HDD)
+
+@item HAMX
+Hardware Accelerated eXcution Manager (Intel)
+
 @item HAND
 Have A Nice Day (slang, Usenet, IRC)
 
 @item HANFS
 Highly Available Network File System
 
+@item HAP
+High Assurance Platform (NSA, TCG)
+
 @item HAP
 Host Access Protocol (RFC 907/1221)
 
@@ -72,15 +81,27 @@ High AVailability
 @item HAVI
 Home Audio Video Interoperability (org., Grundig, Hitachi, Matsushita, Philips, Sharp, Sony, Thomson, Toshiba)
 
+@item HAXM
+Hardware Accelerated eXecution Manager (Intel)
+
 @item HBA
 Host Bus Adapter (SCSI)
 
 @item HBAO
 Horizon-Based Ambient Occlusion (SSAO)
 
+@item HBBTV
+Hybrid Broadcast Broadband TV, "HbbTV"
+
 @item HBCI
 HomeBanking Computer Interface [old term] Internet, banking, Germany, HBCI
 
+@item HBM
+High Bandwidth Memory (DRAM, JEDEC)
+
+@item HBM
+Host Buffer Memory (NVMe)
+
 @item HBP
 Human Brain Project (Europe)
 
@@ -157,7 +178,7 @@ Hard Disk Controller
 High Density Compact Disk (CD, Sony, Phillips)
 
 @item HDCP
-High-bandwidth Digital Copy Protection (DRM, HDMI, cryptography)
+High-bandwidth Digital Content Protection (DRM, HDMI, cryptography)
 
 @item HDD
 Hard Disk Drive (HDD)
@@ -180,6 +201,9 @@ Hadoop Distributed File System (Hadoop)
 @item HDH
 HDLC Distant Host
 
+@item HDI
+High Density Interconnect
+
 @item HDI
 HOOPS Device Interface (VAGI)
 
@@ -243,6 +267,9 @@ HoehenEinheit [1HE = 19"]
 @item HEA
 Hyundai Electronics of America (manufacturer)
 
+@item HEAAC
+High Efficiency Advanced Audio Coding, "HE-ACC"
+
 @item HEC
 HDMI Ethernet Channel (HDMI)
 
@@ -255,6 +282,12 @@ Header Error Control (ATM)
 @item HECTOR
 HEterogeneous Computer TOgetheR (IBM, Uni Karlsruhe, Germany)
 
+@item HEDT
+High-End DeskTop (Intel)
+
+@item HEIF
+High Efficiency Image File format (MPEG)
+
 @item HEL
 Hardware Emulation Layer
 
@@ -309,6 +342,9 @@ Hierachical File System (Apple, CD, MACOS)
 @item HFT
 High Function Terminal (AIX, IBM)
 
+@item HFTS
+Hybrid Frustrum Traced Shadows (Nvidia)
+
 @item HGA
 Hercules Graphics Adapter
 
@@ -333,12 +369,18 @@ Handover Interface 2 (ETSI, ES 201671)
 @item HI3
 Handover Interface 3 (ETSI, ES 201671)
 
+@item HIBP
+Have I Been Pwned
+
 @item HIC
 Human Interaction Component
 
 @item HIC
 Hybrid Integrated Circuit
 
+@item HICANN
+High Input Count Analog Neural Network
+
 @item HID
 Human Interface Device (MS)
 
@@ -363,6 +405,9 @@ Human Interface Graphical GENeration System (Uni Colorado)
 @item HINT
 Hierarchical INTegration [benchmark]
 
+@item HIP
+Host Identity Protocol (IETF)
+
 @item HIPERLAN
 HIgh PErformance Radio Local Area Network (LAN, ETSI, EN 300 652)
 
@@ -387,6 +432,9 @@ HIgh SPeed channel connector (Cray, I/O)
 @item HKS
 Horowitz Key Server (PGP, GPG, PKS, SKS)
 
+@item HLG
+Hybrid-Log Gamma (HDR, TV, BBC, NHK)
+
 @item HLL
 High Level Language
 
@@ -405,6 +453,12 @@ Home Location Register (LR, GSM, GPRS, mobile-systems)
 @item HLRB
 HoechstLeistungsRechenzentrum Bayern (org.)
 
+@item HLRS
+HoechstLeistungsRechenzentrum Stuttgart (org.)
+
+@item HLS
+HTTP Live Streaming (Apple, HTTP)
+
 @item HLS
 Hue, Luminance, Saturation (color system, DTP)
 
@@ -426,12 +480,18 @@ Hardware Management Console (IBM, Linux)
 @item HMC
 Highspeed Memory Controller (Apple)
 
+@item HMC
+Hybrid Memory Cube (DRAM)
+
 @item HMD
 Head Mounted Display (VR)
 
 @item HMI
 Human-Machine Interface
 
+@item HMM
+Heterogeneous Memory Management
+
 @item HMMP
 HyperMedia Management Protocol (MS, Intel, Cisco, WWW, HMMS)
 
@@ -450,12 +510,18 @@ Hybrid MUltipleXer (FDDI), "H-MUX"
 @item HNA
 Host and Network Association [message] (OLSR)
 
+@item HNCP
+HomeNet Control Protocol
+
 @item HNF
 Heinz Nixdorf Museumsforum (org., Paderborn, Germany)
 
 @item HNI
 Heinz Nixdorf Institut (org., ZIT)
 
+@item HOA
+High Order Ambisonics (MPEG)
+
 @item HOD
 Host On Demand (IBM, HOD)
 
@@ -480,6 +546,12 @@ Half Object Plus Protocol
 @item HOS
 High Order Surfaces (3D)
 
+@item HOT
+Heat Orchestration Template
+
+@item HOTP
+HMAC-based One-time Password (HMAC)
+
 @item HP
 Hewlett Packard (manufacturer)
 
@@ -504,6 +576,9 @@ High Performance Communication Server (Tobit, NLM, Netware)
 @item HPCS
 High Productivity Computing System (DARPA, Cray, IBM, Sun, ...)
 
+@item HPE
+Hewlett Packard Enterprise (HP, manufacturer)
+
 @item HPET
 High Precision Event Timer (IC, Intel, MS)
 
@@ -511,7 +586,10 @@ High Precision Event Timer (IC, Intel, MS)
 High Performance FORTRAN (FORTRAN)
 
 @item HPFS
-High Performance FileSystem (OS/2)
+High Performance FileSystem (OS/2, FS)
+
+@item HPG
+High Performance Group (org., SPEC)
 
 @item HPGL
 Hewlett Packard Graphics Language (CAD, CAM, HP)
@@ -519,6 +597,9 @@ Hewlett Packard Graphics Language (CAD, CAM, HP)
 @item HPIB
 Hewlett Packard Interface Bus (GPIB)
 
+@item HPKP
+HTTP Public Key Pinning (HHTP, cryptography)
+
 @item HPLIP
 Hewlett Packard Linux Imaging and Printing (HP, Linux)
 
@@ -586,7 +667,7 @@ Home Radio Frequency Working Group (WLAN, HOMERF)
 Human Resource Management System (Peoplesoft)
 
 @item HRTF
-Head Related Transfer Function
+Head Related Transfer Function (VR)
 
 @item HS
 High Speed (MODEM)
@@ -700,7 +781,7 @@ High Soft Tech (manufacturer, ISDN)
 High Speed Technology (US Robotics)
 
 @item HSTS
-HTTP Strict Transport Security (HTTP, cryptography)
+HTTP Strict Transport Security (HTTP, cryptography, RFC 6797)
 
 @item HSUPA
 High Speed Uplink Packet Access (UMTS, HSDPA)
@@ -804,9 +885,15 @@ Holografic Versatile Disc
 @item HVD
 Hosted Virtual Desktop
 
+@item HVGA
+Half Video Graphics Array [320480] (VGA)
+
 @item HVM
 Hardware Virtual Machine
 
+@item HWE
+HardWare Enablement [stack]] (Linux, Ubuntu)
+
 @item HWMC
 HardWare Motion Compensation
 
