@@ -1,6 +1,6 @@
 @c -*-texinfo-*-
 @c This is part of the GNU edition of V.E.R.A.
-@c Copyright (C) 1993/2014 Oliver Heidelbach
+@c Copyright (C) 1993/2020 Oliver Heidelbach
 @c See the file vera.texi for copying conditions.
 @c 
 @c Syntax:
@@ -93,6 +93,9 @@ Multi Access Module
 @item MAME
 Multiple Arcade Machine Emulator, "M.A.M.E."
 
+@item MAMP
+Mac, Apache, MySQL, PHP (Mac, Apache, PHP, DB, SQL)
+
 @item MAN
 Metropolitan Area Network
 
@@ -109,7 +112,7 @@ Manufacturing Automation Protocol (General Motors)
 Microsoft Academic Program (MS)
 
 @item MAP
-Mobile Application Part (MSC, GSM, mobile-systems)
+Mobile Application Part (MSC, GSM, mobile-systems, SS7)
 
 @item MAP27
 Mobile Access Protocol [for MPT 1327] (MPT 1327), "MAP 27"
@@ -126,6 +129,9 @@ Messaging Application Program Interface (MS, WOSA, API)
 @item MAPOS
 Multiple Access Protocol over SONET/SDH (SONET, SDH, RFC 2171)
 
+@item MAPP
+Mac, Apache, PostgreSQL, PHP (Mac, Apache, PHP, DB, SQL)
+
 @item MAPP
 Microsoft Active Protections Program (MS)
 
@@ -159,6 +165,9 @@ Mittelstands-Anwendungs-System 90 (IBM)
 @item MASC
 Multicast Address-Set Claim [protocol] (RFC 2909, Multicast)
 
+@item MASCAT
+MicroArchitectural Side-Channel Attack
+
 @item MASE
 Message Administration Service Element
 
@@ -168,6 +177,9 @@ Microsoft ASseMbler (MS, assembler)
 @item MASS
 Message Authentication Signature Standards (MTA, SPAM, WG)
 
+@item MAT
+[Dolby] Metadata-enhanced Audio Transmission
+
 @item MAU
 Medium Access Unit
 
@@ -204,9 +216,18 @@ MegaByte
 @item MBA
 Memory Bus Adapter
 
+@item MBA
+Mobile Bitstream Access (mobile-systems)
+
+@item MBAAS
+Mobile Backend As A Service (BAAS)
+
 @item MBAG
 Mercedes-Benz AktienGesellschaft (user)
 
+@item MBB
+Mobile BroadBand (3GPP)
+
 @item MBC
 Multi Bit Cell (IC, PCMCIA, Flash, AMD, BIT)
 
@@ -243,6 +264,9 @@ Microsoft Business and Services Agreement (MS)
 @item MBUS
 Module BUS [standard] (Sun, SPARC), "MBus"
 
+@item MC2UC
+MultiCast 2 UniCast (WLAN)
+
 @item MCA
 Micro Channel Architecture (IBM, PS/2)
 
@@ -273,6 +297,9 @@ Manchester Computing Centre (Linux)
 @item MCC
 Mitteldeutsches Communication Center (Leipzig)
 
+@item MCC
+Mobile Country Code (mobile-systems)
+
 @item MCC
 Monitor and Control Center (Bundeswehr)
 
@@ -396,6 +423,9 @@ Message Conversion System Message Processor (MCS)
 @item MCSS
 Mitac Computer Security System (Mitac)
 
+@item MCT
+Media Creation Tool (MS, Windows)
+
 @item MCT
 Microsoft Certified Trainer (MS, ATEC)
 
@@ -414,6 +444,9 @@ Master Control Unit (Nokia, OS)
 @item MCU
 Micro Controller Unit (SIA, RL)
 
+@item MCU
+Mirco Code Update
+
 @item MCU
 Multipoint Controller Unit (VoiP)
 
@@ -468,6 +501,9 @@ Message conversion system Directory Component (MCS)
 @item MDC
 Meta Data Coalition
 
+@item MDC
+Mozilla Developer Center
+
 @item MDCT
 Modified Discrete Cosine Transformation
 
@@ -514,7 +550,13 @@ Master Data Management
 MicroDiskModule
 
 @item MDM
-Mobile Device Management (CA, Unicenter)
+Mobile Device Management (CA, Unicenter, MS)
+
+@item MDN
+Mozilla Developer Network
+
+@item MDNS
+Multicast - Domain Name System (DNS), "mDNS"
 
 @item MDOP
 Microsoft Desktop Optimization Pack (MS, Windows)
@@ -555,6 +597,9 @@ Mittlere DatenTechnik
 @item MDT
 Mountain Daylight Time [-0600] (TZ, MST, USA)
 
+@item ME
+Management Engine (Intel, AMT, BIOS, UEFI)
+
 @item ME
 Mapping Entity
 
@@ -780,6 +825,9 @@ Movie In A Window
 @item MIB
 Management Information Base (OSI, SNMP)
 
+@item MIC
+Machine Identification Code
+
 @item MIC
 Media Interface Connector (FDDI, PMD)
 
@@ -832,7 +880,7 @@ Mobile Information Device Profile Expert Group (Sun, AOL, Motorola, NEC, Nokia,
 Module Interconnection Facility (Proteus)
 
 @item MIG
-Mach Interface Generator (Mach)
+Mach Interface Generator (Mach, IDL)
 
 @item MII
 Media Independent Interface
@@ -865,10 +913,10 @@ Multiple Instruction [stream], Multiple Data [stream] (CPU)
 Multipurpose Internet Mail Extensions (RFC 2045/2046/2047/2048/2049, IETF)
 
 @item MIMO
-Multiple Input, Multiple Output (WLAN)
+Multiple Input, Multiple Output (Agere-Systems, WLAN, Bell)
 
 @item MIMO
-Multiple Input, Multiple Output (Agere-Systems, WLAN, Bell)
+Multiple Input, Multiple Output (WLAN)
 
 @item MIMOLA
 Machine Independent MicrOprogramming LAnguage (HDL)
@@ -912,6 +960,9 @@ Microprocessor without Interlocked Piped Stages
 @item MIPS
 Million Instructions Per Second (CPU)
 
+@item MIPV6
+Mobile IP V6 (IP), "MIPv6"
+
 @item MIR
 Maximum Information Rate
 
@@ -969,6 +1020,9 @@ Mortice Kern Systems (manufacturer)
 @item MKT
 Multifunktionelles KartenTerminal (CT, ICC)
 
+@item ML
+Machine Learning
+
 @item ML
 Mail List
 
@@ -1026,6 +1080,9 @@ MultiLink Point-to-Point Protocol (PPP)
 @item MLR
 Multi-channel Linear Recording [technology] (Tandberg, Streamer)
 
+@item MLS
+Messaging Layer Security (IETF)
+
 @item MLS
 MultiLevel Secure [operating systems / platforms] (SELinux)
 
@@ -1116,6 +1173,9 @@ Massive Multiplayer Online Games
 @item MMORPG
 Massive Multiplayer Online RolePlaying Games
 
+@item MMOS
+Massive Multiplayer Online Science (MMO)
+
 @item MMP
 Multilink Multichasis PPP (PPP)
 
@@ -1146,6 +1206,9 @@ Multilevel Mail Server
 @item MMS
 Multimedia Messaging Service (mobile-systems)
 
+@item MMTC
+Massive Machine-Type Communication (MTC, 3GPP), "M-MTC"
+
 @item MMU
 Mass Memory Unit
 
@@ -1164,6 +1227,9 @@ Mobile Module PCI eXpress [specificiation] (Nvidia, PCIe)
 @item MMX
 MultiMedia eXtensions (Intel, CPU)
 
+@item MNC
+Mobiles Network Codes (mobile-systems)
+
 @item MNG
 Multiple-image Network Graphics [format]
 
@@ -1185,6 +1251,9 @@ Memory Ordering Buffer (Intel, CPU)
 @item MOBA
 Multiplayer Online Battle Arena (ARTS, RTS)
 
+@item MOBI
+Mobility Open Blockchain Initiative (org.)
+
 @item MOCS
 Microsoft Official Curriculum Seminar (MS, ATEC, MCSD)
 
@@ -1200,6 +1269,9 @@ Mixed Object Document Content Architecture (IBM), "MO:DCA"
 @item MODEM
 MOdulator DEModulator
 
+@item MODI
+Microsoft Office Document Imaging (MS)
+
 @item MOE
 Measure of Effectiveness
 
@@ -1227,6 +1299,9 @@ Molecule Organic Light Emitting Display (OLED)
 @item MOLI
 Microsoft OnLine Institute (MS)
 
+@item MOLO
+Mobile Other Licensed Operator (mobile-systems, MVNO)
+
 @item MOLP
 Microsoft Open Licence Pack (MS)
 
@@ -1258,7 +1333,7 @@ Meta Object Protocol (CLOS)
 Multiple Original Prints
 
 @item MOPRIA
-MObile PRinting Alliance (org., Canon, HP, Samsung, Xerox)
+MObile PRinting Alliance (org., Canon, HP, Samsung, Xerox), "Mopria"
 
 @item MOPS
 Million Operations Per Second
@@ -1281,6 +1356,9 @@ Multiprogramming Operating System (OS, NCR)
 @item MOSA
 Microsoft Online Subscription Agreement (MS)
 
+@item MOSA
+Multiplayer Online Survival Arena
+
 @item MOSES
 Major Open Systems Environment Standards
 
@@ -1458,6 +1536,9 @@ Maet- och Provningsradet [National Board for Measurement and Testing] (org., Swe
 @item MPR
 MultiPoint Relay (OLSR)
 
+@item MPRT
+Moving Picture Response Time
+
 @item MPS
 Megabytes Per Second
 
@@ -1521,9 +1602,18 @@ MultiProgramming eXecutive (IBM, OS, IBM 1800)
 @item MPX
 MultiProgramming eXecutive (OS)
 
+@item MQA
+Master Quality Authenticated (audio)
+
 @item MQI
 Message Queueing Interface (IBM)
 
+@item MQT
+Materialized Query Table (IBM, DB)
+
+@item MQTT
+Message Queuing Telemetry Transport
+
 @item MQUIPS
 Million QUality Improvements Per Second
 
@@ -1647,6 +1737,9 @@ MicroService Architecture (SOA)
 @item MSA
 MultiSource Assignment
 
+@item MSAN
+Multi-Server Access Node
+
 @item MSAP
 Management Service Access Point (OSI, OSI/RM, SAP)
 
@@ -1662,6 +1755,9 @@ Most Significant Bit (BIT)
 @item MSBA
 Microsoft Baseline Security Analyzer (MS)
 
+@item MSC
+Microprocessor Standardization Committee (Oerg., IEEE)
+
 @item MSC
 MicroSoft C
 
@@ -1716,6 +1812,9 @@ Multicast Source Discovery Protocol (Internet, PIM-SM, Multicast, RFC 3618)
 @item MSE
 Mean Squared Error
 
+@item MSE
+Media Source Extensions (W3C, HTML, Javascript)
+
 @item MSE
 MicroSoft Exchange server (MS)
 
@@ -1764,6 +1863,9 @@ Metered Services Information eXchange [protocol] (Internet, ISP)
 @item MSJVM
 MicroSoft Java Virtual Machine (MS, Java)
 
+@item MSL
+Master Security Lock (mobile-systems)
+
 @item MSL
 Maximum Segment Lifetime (TCP/IP)
 
@@ -1830,6 +1932,9 @@ Mobile Support Router (MHP)
 @item MSR
 Model Specific Register (Intel, Pentium, IC)
 
+@item MSRC
+Microsoft Security Response Center (MS)
+
 @item MSRL
 MicroSoft Reciprocal License (MS, Ms-PL), "Ms-RL"
 
@@ -1860,6 +1965,9 @@ Message Submission Service Element
 @item MST
 Mountain Standard Time [-0700] (TZ, MDT, USA)
 
+@item MST
+Multi-Stream Transport
+
 @item MSTP
 Multiple Spanning Tree Protocol (STP, VLAN, IEEE 802.1s)
 
@@ -1911,6 +2019,9 @@ Mean Time Between Failure (HDD, ...)
 @item MTBRP
 Mean-Time-Between-Parts-Replacement
 
+@item MTC
+Machine-Type Communication (3GPP)
+
 @item MTC
 Master Test Component (ISO 9646-3, TTCN)
 
@@ -1960,7 +2071,7 @@ Media Transfer Protocol (Windows, MCE)
 Memory Translation and Protection (Infiniband)
 
 @item MTP
-Message Transfer Part (ISDN, GSM, mobile-systems)
+Message Transfer Part (ISDN, GSM, mobile-systems, SS7)
 
 @item MTR
 Mining Table Repository (OP, Oracle, DB)
@@ -1986,6 +2097,9 @@ Microsoft Transaction Server (MS, DB, WSH, COM)
 @item MTT
 MailTrusT (cryptography)
 
+@item MTT
+Multiple Transaction Translator
+
 @item MTTF
 Mean Time To Failure
 
@@ -2037,6 +2151,9 @@ MULTiplexed Information and Computing Service (OS, MIT, Bell)
 @item MULTOS
 MULtimedia Office Server (OA, BIS, ESPRIT)
 
+@item MUMIMO
+Multi User Multiple Input Multiple Output (WLAN), "MU-MIMO"
+
 @item MUMPS
 Massachusetts general hospital Utility Multi-Programming System
 
@@ -2062,7 +2179,7 @@ Master Upper Tester (ISO 9646-3, TTCN)
 ???, "MuTIOI"
 
 @item MUTOS
-MultiUser-/multitasking Operating System (GDR, OS)
+MultiUser-/multitasking Timesharing Operating System (GDR, OS)
 
 @item MUEW
 eW MonopolUEbertragungsWeg, "MueW"
@@ -2091,6 +2208,9 @@ Motion Video Instructions (DEC, CPU, Alpha)
 @item MVIF
 Multi-Vendor Interacting Forum (org., IN)
 
+@item MVNO
+Mobile Virtual Network Operator (mobile-systems, MOLO)
+
 @item MVP
 Most Valuable Professional [bonus program] (MS)
 
