@@ -1,6 +1,6 @@
 @c -*-texinfo-*-
 @c This is part of the GNU edition of V.E.R.A.
-@c Copyright (C) 1993/2014 Oliver Heidelbach
+@c Copyright (C) 1993/2020 Oliver Heidelbach
 @c See the file vera.texi for copying conditions.
 @c 
 @c Syntax:
@@ -102,6 +102,9 @@ Remote Access Maintenance Protocol
 @item RAMPS
 Reliability, Availability, Manageability, Performance and Scalability (DB)
 
+@item RAMPS
+Reprap Arduino Mega Pololu Shield (Arduino)
+
 @item RAMS
 Record Archival Management System
 
@@ -174,6 +177,9 @@ Role Based Access Control (SELinux)
 @item RBBS
 Remote Bulletin Board System (BBS)
 
+@item RBE
+Rust By Example
+
 @item RBF
 Random Block Filemanager (OS-9)
 
@@ -273,6 +279,9 @@ Resource Construction Set
 @item RCS
 Revision Control System (Unix, CM, GNU)
 
+@item RCS
+Rich Communications Services (GSM, mobile-systems)
+
 @item RCTC
 Rewritable Consumer Time Code (video)
 
@@ -357,6 +366,9 @@ RSA-DES-Hybridverschluesselung (cryptography, HBCI)
 @item RDI
 Remote Defect Identification / Indicator (UNI)
 
+@item RDIMM
+Registered Dual Inline Memory Module (DIMM, IC)
+
 @item RDL
 Relational Database Language (DB)
 
@@ -453,6 +465,9 @@ Reach Extended Asymmetric Digital Subscriber Line (ADSL, DSL), "RE ADSL"
 @item REBOL
 Relative Expression Based Object Language
 
+@item REFS
+Resilient File System (MS, FS), "ReFS"
+
 @item REGEX
 REGular EXpressions (GREP, EMACS, ...)
 
@@ -480,6 +495,9 @@ Resources Management On-Line System
 @item REPL
 Read Eval Print Loop
 
+@item RERAM
+Resistive Random Access Memory (RAM, IC), "ReRAM"
+
 @item RES
 Remote Entry Services
 
@@ -504,6 +522,9 @@ Restructured EXtended eXecutor [language] (IBM, SAA, ANSI)
 @item RF
 Radio Frequency (mobile-systems)
 
+@item RF4CE
+Radio Frequency 4 Consumer Electronics
+
 @item RFA
 Request for Assistance (Internet)
 
@@ -597,6 +618,9 @@ Red Green Blue Alpha-[byte] (color system, RGB)
 @item RGBE
 Red Green Blue Emerald (color system, photo, Sony)
 
+@item RGMII
+Reduced Gigabit Media Independent Interface
+
 @item RGMS
 Rotated Grid MultiSampling (graphics)
 
@@ -624,6 +648,9 @@ Red Hat Enterprise Linux (Linux, RedHat)
 @item RHS
 Right Hand Side (NGSCB, MS, Palladium)
 
+@item RHSCL
+Red Hat Sofetware CoLection (Linux, Red Hat)
+
 @item RI
 Reference Implementation (JCP)
 
@@ -711,6 +738,9 @@ Reseaux IP Europeenne (Europenet)
 @item RIPL
 Remote Initial Program Load (IBM)
 
+@item RIPN
+Russian Institute for Public Networks (org.)
+
 @item RIPNG
 Routing Information Protocol Next Generation (RIP, IPV6, RFC 2080), "RIPng"
 
@@ -729,6 +759,9 @@ Reduced Instruction Set Code (CPU)
 @item RISC
 Research Institute for Symbolic Computation (org., Austria)
 
+@item RISC
+Risk and Incident Sharing and Coordination (IETF, OpenID)
+
 @item RISCOS
 RISC Operating System (MIPS, Acorn, OS), "RISC OS"
 
@@ -939,15 +972,24 @@ Read-Only (I/O)
 @item ROAMS
 Reusable Object Access and Management System
 
+@item ROBOT
+Return Of Bleichenbacher's Oracle Threat (TLS, RSA)
+
 @item ROC
 RAID On a Chip (RAID)
 
 @item ROC
 Reconstruction Of Color (ICE, Scanner)
 
+@item ROCA
+Return Of the Coppersmith Attack (RSA, TPM)
+
 @item ROCF
 Remote Object Class Factory
 
+@item ROCM
+Radeon Open CoMpute (AMD), "ROCm"
+
 @item ROD
 Rewritable Optical Disk (OD)
 
@@ -984,18 +1026,27 @@ Required Operational Messaging Characteristics
 @item ROMP
 Research Office products division MultiProcessor (IBM, AIX)
 
+@item ROP
+Raster Operation Processor (GPU)
+
 @item ROP
 Remote Operations Service (IBM, OS/2)
 
 @item ROP
 Return Orientated Programming
 
+@item ROPO
+Research Online, Purchase Offline
+
 @item ROS
 Read-Only Storage
 
 @item ROS
 Resident Operating System (OS)
 
+@item ROS
+Robot Operating System (OS)
+
 @item ROSE
 [CAE] Real-time Object-based Simulation Environment
 
@@ -1060,7 +1111,7 @@ RePeat active File (IBM, VM/ESA, CP)
 Reverse Path Forwarding (PIM, Multicast)
 
 @item RPG
-Report Program Generator
+Report Program Generator (IBM)
 
 @item RPG
 Role Playing Game
@@ -1083,6 +1134,9 @@ Redhat Package Manager (Linux)
 @item RPM
 Remote Port Module (Ascend)
 
+@item RPMA
+Random Phase Multiple Access (IoT, LP-WAN)
+
 @item RPN
 Reverse Polish Notation
 
@@ -1095,6 +1149,9 @@ Read Port Status (FCP)
 @item RPS
 Realtime Programming System (OS, IBM)
 
+@item RPZ
+Response Policy Zone (DNS, BIND)
+
 @item RQBE
 Relational Query By Example (DB, QBE)
 
@@ -1113,6 +1170,9 @@ Relative Record Data Set (VSAM)
 @item RRIP
 Rock Ridge Interchange Protocol (CD, Unix)
 
+@item RRL
+Response Rate Limiting (BIND)
+
 @item RRO
 Radial Run Out (DVD)
 
@@ -1122,6 +1182,9 @@ Red Ring Of Death (MS, Xbox)
 @item RRP
 Registry Registrar Protocol (VeriSign, RFC 2832/3632)
 
+@item RRT
+Retirement Register File (Intel, CPU)
+
 @item RRZE
 Regionales RechenZentrum Erlangen (org.)
 
@@ -1380,6 +1443,9 @@ ReTurn from Interrupt
 @item RTIN
 Request Topology INformation (FCP, SNIA, HBA, API)
 
+@item RTK
+Real Time Kinematic
+
 @item RTL
 Real Time Language
 
@@ -1518,12 +1584,18 @@ Rechenzentrum der Universitaet Stuttgart (org., Uni Stuttgart, Germany)
 @item RUTE
 RUTE Users Tutorial and Exposition (Unix), "R.U.T.E."
 
+@item RUU
+ROM Upgrade Utility (HTC, ROM)
+
 @item RVC
 Ruby VSphere Console (VSAN), "RvC"
 
 @item RVD
 Remote Virtual Disk
 
+@item RVI
+Rapid Virtualization Indexing (SLAT, AMD)
+
 @item RVPPIP
 Rendez-Vous Protocol / Presence Information Protocol (IM), "RVP/PIP"
 
@@ -1533,6 +1605,9 @@ Read/Write (I/O), "R/W"
 @item RWCP
 Real World Computing Partnership (org., Japan)
 
+@item RWD
+Responsive Web Design (WWW)
+
 @item RWPPI
 ReWritable Product Promotion Initiative (org., DVD-R, DVD-RW, DVD)
 
